@@ -36,7 +36,7 @@ class Profile(object):
 
     def __init__(self, session, username):
         """
-        :param session: A logged in :class:`okcupyd.session.Session`
+        :param session: A logged in :class:`~okcupyd.session.Session`
         :param username: The username associated with the profile.
         """
         self._session = session
@@ -102,25 +102,29 @@ class Profile(object):
     def authcode(self):
         return helpers.get_authcode(self.profile_tree)
 
+
+    _photo_info_xpb = xpb.div.with_class('photo').img.select_attribute_('src')
     @util.cached_property
     def photo_infos(self):
         """
-        :returns: list of :class:`okcupyd.photo.Info` instances for each photo
+        :returns: list of :class:`~okcupyd.photo.Info` instances for each photo
                   displayed on okcupid.
         """
-        pics_request = self._session.okc_get(
-            u'profile/{0}/photos#0'.format(self.username)
-        )
-        pics_tree = html.fromstring(pics_request.content.decode('utf8'))
         from . import photo
-        return map(photo.Info.from_cdn_uri,
-                   xpb.div(id='album_0').img.select_attribute_('src',
-                                                               pics_tree))
+        pics_request = self._session.okc_get(
+            u'profile/{0}/album/0'.format(self.username),
+        )
+        pics_tree = html.fromstring('{0}{1}{2}'.format(
+            '<div>', pics_request.json()['fulls'], '</div>'
+        ))
+        return [photo.Info.from_cdn_uri(uri)
+                for uri in self._photo_info_xpb.apply_(pics_tree)]
+
 
     @util.cached_property
     def looking_for(self):
         """
-        :returns: A :class:`okcupyd.looking_for.LookingFor` instance associated
+        :returns: A :class:`~okcupyd.looking_for.LookingFor` instance associated
                   with this profile.
         """
         return looking_for.LookingFor(self)
@@ -186,7 +190,7 @@ class Profile(object):
     @util.cached_property
     def essays(self):
         """
-        :returns: An :class:`okcupyd.essay.Essays` instance that is associated with
+        :returns: An :class:`~okcupyd.essay.Essays` instance that is associated with
                   this profile.
         """
         return essay.Essays(self)
@@ -297,7 +301,7 @@ class Profile(object):
 
     def question_fetchable(self, **kwargs):
         """
-        :returns: A :class:`okcupyd.util.fetchable.Fetchable` instance that
+        :returns: A :class:`~okcupyd.util.fetchable.Fetchable` instance that
                   contains objects representing the answers that the user
                   associated with this profile has given to okcupid.com match
                   questions.
